@@ -15,6 +15,8 @@ from django.forms.models import _get_foreign_key
 from django.utils.functional import cached_property
 from django.urls import reverse
 
+import import_string
+
 from is_core.auth.permissions import FieldsSetPermission
 from is_core.config import settings
 from is_core.actions import WebAction, ConfirmRESTAction
@@ -23,11 +25,12 @@ from is_core.generic_views.table_views import TableView
 from is_core.rest.resource import RESTModelResource
 from is_core.rest.paginators import OffsetBasedPaginator
 from is_core.patterns import UIPattern, RESTPattern, DoubleRESTPattern, HiddenRESTPattern
-from is_core.utils import flatten_fieldsets, str_to_class, GetMethodFieldMixin, get_model_name, PK_PATTERN
+from is_core.utils import flatten_fieldsets,  GetMethodFieldMixin, get_model_name, PK_PATTERN
 from is_core.menu import LinkMenuItem
 from is_core.loading import register_core
 from is_core.rest.factory import modelrest_factory
 from is_core.forms.models import SmartModelForm
+from is_core.utils.decorators import short_description
 
 from .auth.permissions import PermissionsSet, IsAdminUser
 
@@ -107,9 +110,6 @@ class ISCore(metaclass=ISCoreBase):
     def get_urls(self):
         return ()
 
-    def get_views(self):
-        return {}
-
     def get_menu_groups(self):
         menu_groups = list(self.menu_parent_groups)
         if self.menu_group:
@@ -353,7 +353,7 @@ class HomeUIISCore(UIISCore):
 
     def get_view_classes(self):
         view_classes = super().get_view_classes()
-        view_classes.append(('index', r'', str_to_class(settings.HOME_VIEW)))
+        view_classes.append(('index', r'', import_string(settings.HOME_VIEW)))
         return view_classes
 
     def menu_url(self, request):
@@ -742,6 +742,7 @@ class UIRESTModelISCore(UIRESTISCoreMixin, RESTModelISCore, UIModelISCore):
                     web_links[pattern.name] = url
         return web_links
 
+    @short_description(_('object name'))
     def _obj_name(self, obj):
         return str(obj)
 
